from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopAbs import *
from OCC.Core.TColStd import *
from OCC.Core.TColgp import *
from OCC.Core.gp import *


class HLRAlgo_Array1OfPINod:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class HLRAlgo_Array1OfPISeg:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> HLRAlgo_PolyInternalSegment: ...
    def __setitem__(self, index: int, value: HLRAlgo_PolyInternalSegment) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[HLRAlgo_PolyInternalSegment]: ...
    def next(self) -> HLRAlgo_PolyInternalSegment: ...
    __next__ = next
    def Init(self, theValue: HLRAlgo_PolyInternalSegment) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> HLRAlgo_PolyInternalSegment: ...
    def Last(self) -> HLRAlgo_PolyInternalSegment: ...
    def Value(self, theIndex: int) -> HLRAlgo_PolyInternalSegment: ...
    def SetValue(self, theIndex: int, theValue: HLRAlgo_PolyInternalSegment) -> None: ...

class HLRAlgo_Array1OfTData:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> HLRAlgo_TriangleData: ...
    def __setitem__(self, index: int, value: HLRAlgo_TriangleData) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[HLRAlgo_TriangleData]: ...
    def next(self) -> HLRAlgo_TriangleData: ...
    __next__ = next
    def Init(self, theValue: HLRAlgo_TriangleData) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> HLRAlgo_TriangleData: ...
    def Last(self) -> HLRAlgo_TriangleData: ...
    def Value(self, theIndex: int) -> HLRAlgo_TriangleData: ...
    def SetValue(self, theIndex: int, theValue: HLRAlgo_TriangleData) -> None: ...

class HLRAlgo_InterferenceList:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> HLRAlgo_Interference: ...
    def Last(self) -> HLRAlgo_Interference: ...
    def Append(self, theItem: HLRAlgo_Interference) -> HLRAlgo_Interference: ...
    def Prepend(self, theItem: HLRAlgo_Interference) -> HLRAlgo_Interference: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> HLRAlgo_Interference: ...
    def SetValue(self, theIndex: int, theValue: HLRAlgo_Interference) -> None: ...

class HLRAlgo_ListOfBPoint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> HLRAlgo_BiPoint: ...
    def Last(self) -> HLRAlgo_BiPoint: ...
    def Append(self, theItem: HLRAlgo_BiPoint) -> HLRAlgo_BiPoint: ...
    def Prepend(self, theItem: HLRAlgo_BiPoint) -> HLRAlgo_BiPoint: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> HLRAlgo_BiPoint: ...
    def SetValue(self, theIndex: int, theValue: HLRAlgo_BiPoint) -> None: ...

class HLRAlgo_PolyMask(IntEnum):
	HLRAlgo_PolyMask_EMskOutLin1: int = ...
	HLRAlgo_PolyMask_EMskOutLin2: int = ...
	HLRAlgo_PolyMask_EMskOutLin3: int = ...
	HLRAlgo_PolyMask_EMskGrALin1: int = ...
	HLRAlgo_PolyMask_EMskGrALin2: int = ...
	HLRAlgo_PolyMask_EMskGrALin3: int = ...
	HLRAlgo_PolyMask_FMskBack: int = ...
	HLRAlgo_PolyMask_FMskSide: int = ...
	HLRAlgo_PolyMask_FMskHiding: int = ...
	HLRAlgo_PolyMask_FMskFlat: int = ...
	HLRAlgo_PolyMask_FMskOnOutL: int = ...
	HLRAlgo_PolyMask_FMskOrBack: int = ...
	HLRAlgo_PolyMask_FMskFrBack: int = ...
HLRAlgo_PolyMask_EMskOutLin1 = HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin1
HLRAlgo_PolyMask_EMskOutLin2 = HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin2
HLRAlgo_PolyMask_EMskOutLin3 = HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin3
HLRAlgo_PolyMask_EMskGrALin1 = HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin1
HLRAlgo_PolyMask_EMskGrALin2 = HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin2
HLRAlgo_PolyMask_EMskGrALin3 = HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin3
HLRAlgo_PolyMask_FMskBack = HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskBack
HLRAlgo_PolyMask_FMskSide = HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskSide
HLRAlgo_PolyMask_FMskHiding = HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskHiding
HLRAlgo_PolyMask_FMskFlat = HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFlat
HLRAlgo_PolyMask_FMskOnOutL = HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOnOutL
HLRAlgo_PolyMask_FMskOrBack = HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOrBack
HLRAlgo_PolyMask_FMskFrBack = HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFrBack

class hlralgo:
	@staticmethod
	def EnlargeMinMax(tol: float, Min_list: List[float], Max_list: List[float]) -> None: ...
	@staticmethod
	def InitMinMax(Big: float, Min_list: List[float], Max_list: List[float]) -> None: ...
	@staticmethod
	def UpdateMinMax(x: float, y: float, z: float, Min_list: List[float], Max_list: List[float]) -> None: ...

class HLRAlgo_BiPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, X1: float, Y1: float, Z1: float, X2: float, Y2: float, Z2: float, XT1: float, YT1: float, ZT1: float, XT2: float, YT2: float, ZT2: float, Index: int, reg1: bool, regn: bool, outl: bool, intl: bool) -> None: ...
	@overload
	def __init__(self, X1: float, Y1: float, Z1: float, X2: float, Y2: float, Z2: float, XT1: float, YT1: float, ZT1: float, XT2: float, YT2: float, ZT2: float, Index: int, flag: int) -> None: ...
	@overload
	def __init__(self, X1: float, Y1: float, Z1: float, X2: float, Y2: float, Z2: float, XT1: float, YT1: float, ZT1: float, XT2: float, YT2: float, ZT2: float, Index: int, i1: int, i1p1: int, i1p2: int, reg1: bool, regn: bool, outl: bool, intl: bool) -> None: ...
	@overload
	def __init__(self, X1: float, Y1: float, Z1: float, X2: float, Y2: float, Z2: float, XT1: float, YT1: float, ZT1: float, XT2: float, YT2: float, ZT2: float, Index: int, i1: int, i1p1: int, i1p2: int, flag: int) -> None: ...
	@overload
	def __init__(self, X1: float, Y1: float, Z1: float, X2: float, Y2: float, Z2: float, XT1: float, YT1: float, ZT1: float, XT2: float, YT2: float, ZT2: float, Index: int, i1: int, i1p1: int, i1p2: int, i2: int, i2p1: int, i2p2: int, reg1: bool, regn: bool, outl: bool, intl: bool) -> None: ...
	@overload
	def __init__(self, X1: float, Y1: float, Z1: float, X2: float, Y2: float, Z2: float, XT1: float, YT1: float, ZT1: float, XT2: float, YT2: float, ZT2: float, Index: int, i1: int, i1p1: int, i1p2: int, i2: int, i2p1: int, i2p2: int, flag: int) -> None: ...
	@overload
	def Hidden(self) -> bool: ...
	@overload
	def Hidden(self, B: bool) -> None: ...
	@overload
	def IntLine(self) -> bool: ...
	@overload
	def IntLine(self, B: bool) -> None: ...
	@overload
	def OutLine(self) -> bool: ...
	@overload
	def OutLine(self, B: bool) -> None: ...
	@overload
	def Rg1Line(self) -> bool: ...
	@overload
	def Rg1Line(self, B: bool) -> None: ...
	@overload
	def RgNLine(self) -> bool: ...
	@overload
	def RgNLine(self, B: bool) -> None: ...

class HLRAlgo_Coincidence:
	def __init__(self) -> None: ...
	def Set2D(self, FE: int, Param: float) -> None: ...
	def SetState3D(self, stbef: TopAbs_State, staft: TopAbs_State) -> None: ...
	def State3D(self, stbef: TopAbs_State, staft: TopAbs_State) -> None: ...
	def Value2D(self) -> Tuple[int, float]: ...

class HLRAlgo_EdgeIterator:
	def __init__(self) -> None: ...
	def Hidden(self, TolStart: float, TolEnd: float) -> Tuple[float, float]: ...
	def InitHidden(self, status: HLRAlgo_EdgeStatus) -> None: ...
	def InitVisible(self, status: HLRAlgo_EdgeStatus) -> None: ...
	def MoreHidden(self) -> bool: ...
	def MoreVisible(self) -> bool: ...
	def NextHidden(self) -> None: ...
	def NextVisible(self) -> None: ...
	def Visible(self, TolStart: float, TolEnd: float) -> Tuple[float, float]: ...

class HLRAlgo_EdgeStatus:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Start: float, TolStart: float, End: float, TolEnd: float) -> None: ...
	@overload
	def AllHidden(self) -> bool: ...
	@overload
	def AllHidden(self, B: bool) -> None: ...
	@overload
	def AllVisible(self) -> bool: ...
	@overload
	def AllVisible(self, B: bool) -> None: ...
	def Bounds(self, theTolStart: float, theTolEnd: float) -> Tuple[float, float]: ...
	def Hide(self, Start: float, TolStart: float, End: float, TolEnd: float, OnFace: bool, OnBoundary: bool) -> None: ...
	def HideAll(self) -> None: ...
	def Initialize(self, Start: float, TolStart: float, End: float, TolEnd: float) -> None: ...
	def NbVisiblePart(self) -> int: ...
	def ShowAll(self) -> None: ...
	def VisiblePart(self, Index: int, TolStart: float, TolEnd: float) -> Tuple[float, float]: ...

class HLRAlgo_EdgesBlock(Standard_Transient):
	def __init__(self, NbEdges: int) -> None: ...
	@overload
	def Double(self, I: int) -> bool: ...
	@overload
	def Double(self, I: int, B: bool) -> None: ...
	@overload
	def Edge(self, I: int, EI: int) -> None: ...
	@overload
	def Edge(self, I: int) -> int: ...
	@overload
	def Internal(self, I: int) -> bool: ...
	@overload
	def Internal(self, I: int, B: bool) -> None: ...
	@overload
	def IsoLine(self, I: int) -> bool: ...
	@overload
	def IsoLine(self, I: int, B: bool) -> None: ...
	def MinMax(self) -> False: ...
	def NbEdges(self) -> int: ...
	@overload
	def Orientation(self, I: int, Or: TopAbs_Orientation) -> None: ...
	@overload
	def Orientation(self, I: int) -> TopAbs_Orientation: ...
	@overload
	def OutLine(self, I: int) -> bool: ...
	@overload
	def OutLine(self, I: int, B: bool) -> None: ...

class HLRAlgo_Interference:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Inters: HLRAlgo_Intersection, Bound: HLRAlgo_Coincidence, Orient: TopAbs_Orientation, Trans: TopAbs_Orientation, BTrans: TopAbs_Orientation) -> None: ...
	@overload
	def Boundary(self, B: HLRAlgo_Coincidence) -> None: ...
	@overload
	def Boundary(self) -> HLRAlgo_Coincidence: ...
	@overload
	def BoundaryTransition(self, BTr: TopAbs_Orientation) -> None: ...
	@overload
	def BoundaryTransition(self) -> TopAbs_Orientation: ...
	def ChangeBoundary(self) -> HLRAlgo_Coincidence: ...
	def ChangeIntersection(self) -> HLRAlgo_Intersection: ...
	@overload
	def Intersection(self, I: HLRAlgo_Intersection) -> None: ...
	@overload
	def Intersection(self) -> HLRAlgo_Intersection: ...
	@overload
	def Orientation(self, O: TopAbs_Orientation) -> None: ...
	@overload
	def Orientation(self) -> TopAbs_Orientation: ...
	@overload
	def Transition(self, Tr: TopAbs_Orientation) -> None: ...
	@overload
	def Transition(self) -> TopAbs_Orientation: ...

class HLRAlgo_Intersection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Ori: TopAbs_Orientation, Lev: int, SegInd: int, Ind: int, P: float, Tol: float, S: TopAbs_State) -> None: ...
	@overload
	def Index(self, Ind: int) -> None: ...
	@overload
	def Index(self) -> int: ...
	@overload
	def Level(self, Lev: int) -> None: ...
	@overload
	def Level(self) -> int: ...
	@overload
	def Orientation(self, Ori: TopAbs_Orientation) -> None: ...
	@overload
	def Orientation(self) -> TopAbs_Orientation: ...
	@overload
	def Parameter(self, P: float) -> None: ...
	@overload
	def Parameter(self) -> float: ...
	@overload
	def SegIndex(self, SegInd: int) -> None: ...
	@overload
	def SegIndex(self) -> int: ...
	@overload
	def State(self, S: TopAbs_State) -> None: ...
	@overload
	def State(self) -> TopAbs_State: ...
	@overload
	def Tolerance(self, T: float) -> None: ...
	@overload
	def Tolerance(self) -> float: ...

class HLRAlgo_PolyAlgo(Standard_Transient):
	def __init__(self) -> None: ...
	def Clear(self) -> None: ...
	def Hide(self, status: HLRAlgo_EdgeStatus) -> Tuple[False, int, bool, bool, bool, bool]: ...
	def Init(self, HShell: TColStd_HArray1OfTransient) -> None: ...
	def InitHide(self) -> None: ...
	def InitShow(self) -> None: ...
	def MoreHide(self) -> bool: ...
	def MoreShow(self) -> bool: ...
	def NextHide(self) -> None: ...
	def NextShow(self) -> None: ...
	def PolyShell(self) -> TColStd_Array1OfTransient: ...
	def Show(self) -> Tuple[False, int, bool, bool, bool, bool]: ...
	def Update(self) -> None: ...

class HLRAlgo_PolyData(Standard_Transient):
	def __init__(self) -> None: ...
	@overload
	def FaceIndex(self, I: int) -> None: ...
	@overload
	def FaceIndex(self) -> int: ...
	def HNodes(self, HNodes: TColgp_HArray1OfXYZ) -> None: ...
	def HPHDat(self, HPHDat: HLRAlgo_HArray1OfPHDat) -> None: ...
	def HTData(self, HTData: HLRAlgo_HArray1OfTData) -> None: ...
	def Hiding(self) -> bool: ...
	def Nodes(self) -> TColgp_Array1OfXYZ: ...
	def PHDat(self) -> HLRAlgo_Array1OfPHDat: ...
	def TData(self) -> HLRAlgo_Array1OfTData: ...

class HLRAlgo_PolyInternalData(Standard_Transient):
	def __init__(self, nbNod: int, nbTri: int) -> None: ...
	def DecPINod(self) -> None: ...
	def DecPISeg(self) -> None: ...
	def DecTData(self) -> None: ...
	def Dump(self) -> None: ...
	def IncPINod(self, PINod1: HLRAlgo_Array1OfPINod, PINod2: HLRAlgo_Array1OfPINod) -> None: ...
	def IncPISeg(self, PISeg1: HLRAlgo_Array1OfPISeg, PISeg2: HLRAlgo_Array1OfPISeg) -> None: ...
	def IncTData(self, TData1: HLRAlgo_Array1OfTData, TData2: HLRAlgo_Array1OfTData) -> None: ...
	@overload
	def IntOutL(self) -> bool: ...
	@overload
	def IntOutL(self, B: bool) -> None: ...
	def NbPINod(self) -> int: ...
	def NbPISeg(self) -> int: ...
	def NbTData(self) -> int: ...
	def PINod(self) -> HLRAlgo_Array1OfPINod: ...
	def PISeg(self) -> HLRAlgo_Array1OfPISeg: ...
	@overload
	def Planar(self) -> bool: ...
	@overload
	def Planar(self, B: bool) -> None: ...
	def TData(self) -> HLRAlgo_Array1OfTData: ...
	@overload
	def UpdateLinks(self, TData: HLRAlgo_Array1OfTData, PISeg: HLRAlgo_Array1OfPISeg, PINod: HLRAlgo_Array1OfPINod) -> None: ...
	@overload
	def UpdateLinks(self, ip1: int, ip2: int, ip3: int, TData1: HLRAlgo_Array1OfTData, TData2: HLRAlgo_Array1OfTData, PISeg1: HLRAlgo_Array1OfPISeg, PISeg2: HLRAlgo_Array1OfPISeg, PINod1: HLRAlgo_Array1OfPINod, PINod2: HLRAlgo_Array1OfPINod) -> None: ...

class HLRAlgo_PolyInternalNode(Standard_Transient):
	def __init__(self) -> None: ...

class HLRAlgo_PolyShellData(Standard_Transient):
	def __init__(self, nbFace: int) -> None: ...
	def Edges(self) -> HLRAlgo_ListOfBPoint: ...
	def Hiding(self) -> bool: ...
	def HidingPolyData(self) -> TColStd_Array1OfTransient: ...
	def PolyData(self) -> TColStd_Array1OfTransient: ...
	def UpdateHiding(self, nbHiding: int) -> None: ...

class HLRAlgo_Projector:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, CS: gp_Ax2) -> None: ...
	@overload
	def __init__(self, CS: gp_Ax2, Focus: float) -> None: ...
	@overload
	def __init__(self, T: gp_Trsf, Persp: bool, Focus: float) -> None: ...
	@overload
	def __init__(self, T: gp_Trsf, Persp: bool, Focus: float, v1: gp_Vec2d, v2: gp_Vec2d, v3: gp_Vec2d) -> None: ...
	def Directions(self, D1: gp_Vec2d, D2: gp_Vec2d, D3: gp_Vec2d) -> None: ...
	def Focus(self) -> float: ...
	def FullTransformation(self) -> gp_Trsf: ...
	def InvertedTransformation(self) -> gp_Trsf: ...
	def Perspective(self) -> bool: ...
	@overload
	def Project(self, P: gp_Pnt, Pout: gp_Pnt2d) -> None: ...
	@overload
	def Project(self, P: gp_Pnt) -> Tuple[float, float, float]: ...
	@overload
	def Project(self, P: gp_Pnt, D1: gp_Vec, Pout: gp_Pnt2d, D1out: gp_Vec2d) -> None: ...
	def Scaled(self, On: Optional[bool] = False) -> None: ...
	def Set(self, T: gp_Trsf, Persp: bool, Focus: float) -> None: ...
	def Shoot(self, X: float, Y: float) -> gp_Lin: ...
	@overload
	def Transform(self, D: gp_Vec) -> None: ...
	@overload
	def Transform(self, Pnt: gp_Pnt) -> None: ...
	def Transformation(self) -> gp_Trsf: ...

class HLRAlgo_WiresBlock(Standard_Transient):
	def __init__(self, NbWires: int) -> None: ...
	def MinMax(self) -> False: ...
	def NbWires(self) -> int: ...
	def Set(self, I: int, W: HLRAlgo_EdgesBlock) -> None: ...
	def Wire(self, I: int) -> HLRAlgo_EdgesBlock: ...

#classnotwrapped
class HLRAlgo_TriangleData: ...

#classnotwrapped
class HLRAlgo_PolyInternalSegment: ...

#classnotwrapped
class HLRAlgo_PolyHidingData: ...

# harray1 classes

class HLRAlgo_HArray1OfPINod(HLRAlgo_Array1OfPINod, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> HLRAlgo_Array1OfPINod: ...


class HLRAlgo_HArray1OfPHDat(HLRAlgo_Array1OfPHDat, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> HLRAlgo_Array1OfPHDat: ...


class HLRAlgo_HArray1OfTData(HLRAlgo_Array1OfTData, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> HLRAlgo_Array1OfTData: ...


class HLRAlgo_HArray1OfPISeg(HLRAlgo_Array1OfPISeg, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> HLRAlgo_Array1OfPISeg: ...

# harray2 classes
# hsequence classes

hlralgo_AddMinMax = hlralgo.AddMinMax
hlralgo_CopyMinMax = hlralgo.CopyMinMax
hlralgo_DecodeMinMax = hlralgo.DecodeMinMax
hlralgo_EncodeMinMax = hlralgo.EncodeMinMax
hlralgo_EnlargeMinMax = hlralgo.EnlargeMinMax
hlralgo_InitMinMax = hlralgo.InitMinMax
hlralgo_SizeBox = hlralgo.SizeBox
hlralgo_UpdateMinMax = hlralgo.UpdateMinMax



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Storage import *
from OCC.Core.TCollection import *
from OCC.Core.Message import *
from OCC.Core.TColStd import *
from OCC.Core.CDM import *

#the following typedef cannot be wrapped as is
PCDM_BaseDriverPointer = NewType('PCDM_BaseDriverPointer', Any)

class PCDM_SequenceOfDocument:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class PCDM_SequenceOfReference:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> PCDM_Reference: ...
    def Last(self) -> PCDM_Reference: ...
    def Length(self) -> int: ...
    def Append(self, theItem: PCDM_Reference) -> PCDM_Reference: ...
    def Prepend(self, theItem: PCDM_Reference) -> PCDM_Reference: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> PCDM_Reference: ...
    def SetValue(self, theIndex: int, theValue: PCDM_Reference) -> None: ...

class PCDM_StoreStatus(IntEnum):
	PCDM_SS_OK: int = ...
	PCDM_SS_DriverFailure: int = ...
	PCDM_SS_WriteFailure: int = ...
	PCDM_SS_Failure: int = ...
	PCDM_SS_Doc_IsNull: int = ...
	PCDM_SS_No_Obj: int = ...
	PCDM_SS_Info_Section_Error: int = ...
	PCDM_SS_UserBreak: int = ...
PCDM_SS_OK = PCDM_StoreStatus.PCDM_SS_OK
PCDM_SS_DriverFailure = PCDM_StoreStatus.PCDM_SS_DriverFailure
PCDM_SS_WriteFailure = PCDM_StoreStatus.PCDM_SS_WriteFailure
PCDM_SS_Failure = PCDM_StoreStatus.PCDM_SS_Failure
PCDM_SS_Doc_IsNull = PCDM_StoreStatus.PCDM_SS_Doc_IsNull
PCDM_SS_No_Obj = PCDM_StoreStatus.PCDM_SS_No_Obj
PCDM_SS_Info_Section_Error = PCDM_StoreStatus.PCDM_SS_Info_Section_Error
PCDM_SS_UserBreak = PCDM_StoreStatus.PCDM_SS_UserBreak

class PCDM_TypeOfFileDriver(IntEnum):
	PCDM_TOFD_File: int = ...
	PCDM_TOFD_CmpFile: int = ...
	PCDM_TOFD_XmlFile: int = ...
	PCDM_TOFD_Unknown: int = ...
PCDM_TOFD_File = PCDM_TypeOfFileDriver.PCDM_TOFD_File
PCDM_TOFD_CmpFile = PCDM_TypeOfFileDriver.PCDM_TOFD_CmpFile
PCDM_TOFD_XmlFile = PCDM_TypeOfFileDriver.PCDM_TOFD_XmlFile
PCDM_TOFD_Unknown = PCDM_TypeOfFileDriver.PCDM_TOFD_Unknown

class PCDM_ReaderStatus(IntEnum):
	PCDM_RS_OK: int = ...
	PCDM_RS_NoDriver: int = ...
	PCDM_RS_UnknownFileDriver: int = ...
	PCDM_RS_OpenError: int = ...
	PCDM_RS_NoVersion: int = ...
	PCDM_RS_NoSchema: int = ...
	PCDM_RS_NoDocument: int = ...
	PCDM_RS_ExtensionFailure: int = ...
	PCDM_RS_WrongStreamMode: int = ...
	PCDM_RS_FormatFailure: int = ...
	PCDM_RS_TypeFailure: int = ...
	PCDM_RS_TypeNotFoundInSchema: int = ...
	PCDM_RS_UnrecognizedFileFormat: int = ...
	PCDM_RS_MakeFailure: int = ...
	PCDM_RS_PermissionDenied: int = ...
	PCDM_RS_DriverFailure: int = ...
	PCDM_RS_AlreadyRetrievedAndModified: int = ...
	PCDM_RS_AlreadyRetrieved: int = ...
	PCDM_RS_UnknownDocument: int = ...
	PCDM_RS_WrongResource: int = ...
	PCDM_RS_ReaderException: int = ...
	PCDM_RS_NoModel: int = ...
	PCDM_RS_UserBreak: int = ...
PCDM_RS_OK = PCDM_ReaderStatus.PCDM_RS_OK
PCDM_RS_NoDriver = PCDM_ReaderStatus.PCDM_RS_NoDriver
PCDM_RS_UnknownFileDriver = PCDM_ReaderStatus.PCDM_RS_UnknownFileDriver
PCDM_RS_OpenError = PCDM_ReaderStatus.PCDM_RS_OpenError
PCDM_RS_NoVersion = PCDM_ReaderStatus.PCDM_RS_NoVersion
PCDM_RS_NoSchema = PCDM_ReaderStatus.PCDM_RS_NoSchema
PCDM_RS_NoDocument = PCDM_ReaderStatus.PCDM_RS_NoDocument
PCDM_RS_ExtensionFailure = PCDM_ReaderStatus.PCDM_RS_ExtensionFailure
PCDM_RS_WrongStreamMode = PCDM_ReaderStatus.PCDM_RS_WrongStreamMode
PCDM_RS_FormatFailure = PCDM_ReaderStatus.PCDM_RS_FormatFailure
PCDM_RS_TypeFailure = PCDM_ReaderStatus.PCDM_RS_TypeFailure
PCDM_RS_TypeNotFoundInSchema = PCDM_ReaderStatus.PCDM_RS_TypeNotFoundInSchema
PCDM_RS_UnrecognizedFileFormat = PCDM_ReaderStatus.PCDM_RS_UnrecognizedFileFormat
PCDM_RS_MakeFailure = PCDM_ReaderStatus.PCDM_RS_MakeFailure
PCDM_RS_PermissionDenied = PCDM_ReaderStatus.PCDM_RS_PermissionDenied
PCDM_RS_DriverFailure = PCDM_ReaderStatus.PCDM_RS_DriverFailure
PCDM_RS_AlreadyRetrievedAndModified = PCDM_ReaderStatus.PCDM_RS_AlreadyRetrievedAndModified
PCDM_RS_AlreadyRetrieved = PCDM_ReaderStatus.PCDM_RS_AlreadyRetrieved
PCDM_RS_UnknownDocument = PCDM_ReaderStatus.PCDM_RS_UnknownDocument
PCDM_RS_WrongResource = PCDM_ReaderStatus.PCDM_RS_WrongResource
PCDM_RS_ReaderException = PCDM_ReaderStatus.PCDM_RS_ReaderException
PCDM_RS_NoModel = PCDM_ReaderStatus.PCDM_RS_NoModel
PCDM_RS_UserBreak = PCDM_ReaderStatus.PCDM_RS_UserBreak

class pcdm:
	@overload
	@staticmethod
	def FileDriverType(aFileName: TCollection_AsciiString, aBaseDriver: Storage_BaseDriver) -> PCDM_TypeOfFileDriver: ...

class PCDM_ReadWriter(Standard_Transient):
	@overload
	@staticmethod
	def FileFormat(aFileName: TCollection_ExtendedString) -> TCollection_ExtendedString: ...
	@staticmethod
	def Open(aDriver: Storage_BaseDriver, aFileName: TCollection_ExtendedString, anOpenMode: Storage_OpenMode) -> None: ...
	def ReadDocumentVersion(self, aFileName: TCollection_ExtendedString, theMsgDriver: Message_Messenger) -> int: ...
	def ReadExtensions(self, aFileName: TCollection_ExtendedString, theExtensions: TColStd_SequenceOfExtendedString, theMsgDriver: Message_Messenger) -> None: ...
	def ReadReferenceCounter(self, theFileName: TCollection_ExtendedString, theMsgDriver: Message_Messenger) -> int: ...
	def ReadReferences(self, aFileName: TCollection_ExtendedString, theReferences: PCDM_SequenceOfReference, theMsgDriver: Message_Messenger) -> None: ...
	@staticmethod
	def Reader(aFileName: TCollection_ExtendedString) -> PCDM_ReadWriter: ...
	def Version(self) -> TCollection_AsciiString: ...
	def WriteExtensions(self, aData: Storage_Data, aDocument: CDM_Document) -> None: ...
	@staticmethod
	def WriteFileFormat(aData: Storage_Data, aDocument: CDM_Document) -> None: ...
	def WriteReferenceCounter(self, aData: Storage_Data, aDocument: CDM_Document) -> None: ...
	def WriteReferences(self, aData: Storage_Data, aDocument: CDM_Document, theReferencerFileName: TCollection_ExtendedString) -> None: ...
	def WriteVersion(self, aData: Storage_Data, aDocument: CDM_Document) -> None: ...
	@staticmethod
	def Writer() -> PCDM_ReadWriter: ...

class PCDM_Reader(Standard_Transient):
	def CreateDocument(self) -> CDM_Document: ...
	def GetStatus(self) -> PCDM_ReaderStatus: ...
	@overload
	def Read(self, aFileName: TCollection_ExtendedString, aNewDocument: CDM_Document, anApplication: CDM_Application, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...

class PCDM_Reference:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aReferenceIdentifier: int, aFileName: TCollection_ExtendedString, aDocumentVersion: int) -> None: ...
	def DocumentVersion(self) -> int: ...
	def FileName(self) -> TCollection_ExtendedString: ...
	def ReferenceIdentifier(self) -> int: ...

class PCDM_ReferenceIterator(Standard_Transient):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def Init(self, aMetaData: CDM_MetaData) -> None: ...
	def LoadReferences(self, aDocument: CDM_Document, aMetaData: CDM_MetaData, anApplication: CDM_Application, UseStorageConfiguration: bool) -> None: ...

class PCDM_Writer(Standard_Transient):
	@overload
	def Write(self, aDocument: CDM_Document, aFileName: TCollection_ExtendedString, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...

class PCDM_ReadWriter_1(PCDM_ReadWriter):
	def __init__(self) -> None: ...
	def ReadDocumentVersion(self, aFileName: TCollection_ExtendedString, theMsgDriver: Message_Messenger) -> int: ...
	def ReadExtensions(self, aFileName: TCollection_ExtendedString, theExtensions: TColStd_SequenceOfExtendedString, theMsgDriver: Message_Messenger) -> None: ...
	def ReadReferenceCounter(self, aFileName: TCollection_ExtendedString, theMsgDriver: Message_Messenger) -> int: ...
	def ReadReferences(self, aFileName: TCollection_ExtendedString, theReferences: PCDM_SequenceOfReference, theMsgDriver: Message_Messenger) -> None: ...
	def Version(self) -> TCollection_AsciiString: ...
	def WriteExtensions(self, aData: Storage_Data, aDocument: CDM_Document) -> None: ...
	def WriteReferenceCounter(self, aData: Storage_Data, aDocument: CDM_Document) -> None: ...
	def WriteReferences(self, aData: Storage_Data, aDocument: CDM_Document, theReferencerFileName: TCollection_ExtendedString) -> None: ...
	def WriteVersion(self, aData: Storage_Data, aDocument: CDM_Document) -> None: ...

class PCDM_RetrievalDriver(PCDM_Reader):
	@staticmethod
	def DocumentVersion(theFileName: TCollection_ExtendedString, theMsgDriver: Message_Messenger) -> int: ...
	def GetFormat(self) -> TCollection_ExtendedString: ...
	@staticmethod
	def ReferenceCounter(theFileName: TCollection_ExtendedString, theMsgDriver: Message_Messenger) -> int: ...
	def SetFormat(self, aformat: TCollection_ExtendedString) -> None: ...

class PCDM_StorageDriver(PCDM_Writer):
	def GetFormat(self) -> TCollection_ExtendedString: ...
	def GetStoreStatus(self) -> PCDM_StoreStatus: ...
	def IsError(self) -> bool: ...
	@overload
	def Make(self, aDocument: CDM_Document) -> PCDM_Document: ...
	@overload
	def Make(self, aDocument: CDM_Document, Documents: PCDM_SequenceOfDocument) -> None: ...
	def SetFormat(self, aformat: TCollection_ExtendedString) -> None: ...
	def SetIsError(self, theIsError: bool) -> None: ...
	def SetStoreStatus(self, theStoreStatus: PCDM_StoreStatus) -> None: ...
	@overload
	def Write(self, aDocument: CDM_Document, aFileName: TCollection_ExtendedString, theRange: Optional[Message_ProgressRange] = Message_ProgressRange()) -> None: ...

#classnotwrapped
class PCDM_DOMHeaderParser: ...

#classnotwrapped
class PCDM_Document: ...

# harray1 classes
# harray2 classes
# hsequence classes

pcdm_FileDriverType = pcdm.FileDriverType
pcdm_FileDriverType = pcdm.FileDriverType
PCDM_ReadWriter_FileFormat = PCDM_ReadWriter.FileFormat
PCDM_ReadWriter_FileFormat = PCDM_ReadWriter.FileFormat
PCDM_ReadWriter_Open = PCDM_ReadWriter.Open
PCDM_ReadWriter_Reader = PCDM_ReadWriter.Reader
PCDM_ReadWriter_WriteFileFormat = PCDM_ReadWriter.WriteFileFormat
PCDM_ReadWriter_Writer = PCDM_ReadWriter.Writer
PCDM_RetrievalDriver_DocumentVersion = PCDM_RetrievalDriver.DocumentVersion
PCDM_RetrievalDriver_ReferenceCounter = PCDM_RetrievalDriver.ReferenceCounter



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *
from OCC.Core.BRepAdaptor import *


class IMeshData_Status(IntEnum):
	IMeshData_NoError: int = ...
	IMeshData_OpenWire: int = ...
	IMeshData_SelfIntersectingWire: int = ...
	IMeshData_Failure: int = ...
	IMeshData_ReMesh: int = ...
	IMeshData_UnorientedWire: int = ...
	IMeshData_TooFewPoints: int = ...
	IMeshData_Outdated: int = ...
	IMeshData_Reused: int = ...
	IMeshData_UserBreak: int = ...
IMeshData_NoError = IMeshData_Status.IMeshData_NoError
IMeshData_OpenWire = IMeshData_Status.IMeshData_OpenWire
IMeshData_SelfIntersectingWire = IMeshData_Status.IMeshData_SelfIntersectingWire
IMeshData_Failure = IMeshData_Status.IMeshData_Failure
IMeshData_ReMesh = IMeshData_Status.IMeshData_ReMesh
IMeshData_UnorientedWire = IMeshData_Status.IMeshData_UnorientedWire
IMeshData_TooFewPoints = IMeshData_Status.IMeshData_TooFewPoints
IMeshData_Outdated = IMeshData_Status.IMeshData_Outdated
IMeshData_Reused = IMeshData_Status.IMeshData_Reused
IMeshData_UserBreak = IMeshData_Status.IMeshData_UserBreak

class IMeshData_ParametersList(Standard_Transient):
	def Clear(self, isKeepEndPoints: bool) -> None: ...
	def GetParameter(self, theIndex: int) -> float: ...
	def ParametersNb(self) -> int: ...

class IMeshData_Shape(Standard_Transient):
	def GetShape(self) -> TopoDS_Shape: ...
	def SetShape(self, theShape: TopoDS_Shape) -> None: ...

class IMeshData_StatusOwner:
	def GetStatusMask(self) -> int: ...
	def IsEqual(self, theValue: IMeshData_Status) -> bool: ...
	def IsSet(self, theValue: IMeshData_Status) -> bool: ...
	def SetStatus(self, theValue: IMeshData_Status) -> None: ...
	def UnsetStatus(self, theValue: IMeshData_Status) -> None: ...

class IMeshData_Curve(IMeshData_ParametersList):
	def AddPoint(self, thePoint: gp_Pnt, theParamOnCurve: float) -> None: ...
	def GetPoint(self, theIndex: int) -> gp_Pnt: ...
	def InsertPoint(self, thePosition: int, thePoint: gp_Pnt, theParamOnPCurve: float) -> None: ...
	def RemovePoint(self, theIndex: int) -> None: ...

class IMeshData_Model(IMeshData_Shape):
	def AddEdge(self, theEdge: TopoDS_Edge) -> False: ...
	def AddFace(self, theFace: TopoDS_Face) -> False: ...
	def EdgesNb(self) -> int: ...
	def FacesNb(self) -> int: ...
	def GetEdge(self, theIndex: int) -> False: ...
	def GetFace(self, theIndex: int) -> False: ...
	def GetMaxSize(self) -> float: ...

class IMeshData_PCurve(IMeshData_ParametersList):
	def AddPoint(self, thePoint: gp_Pnt2d, theParamOnPCurve: float) -> None: ...
	def GetFace(self) -> False: ...
	def GetIndex(self, theIndex: int) -> int: ...
	def GetOrientation(self) -> TopAbs_Orientation: ...
	def GetPoint(self, theIndex: int) -> gp_Pnt2d: ...
	def InsertPoint(self, thePosition: int, thePoint: gp_Pnt2d, theParamOnPCurve: float) -> None: ...
	def IsForward(self) -> bool: ...
	def IsInternal(self) -> bool: ...
	def RemovePoint(self, theIndex: int) -> None: ...

class IMeshData_TessellatedShape(IMeshData_Shape):
	def GetDeflection(self) -> float: ...
	def SetDeflection(self, theValue: float) -> None: ...

class IMeshData_Edge(IMeshData_TessellatedShape, IMeshData_StatusOwner):
	def Clear(self, isKeepEndPoints: bool) -> None: ...
	def GetAngularDeflection(self) -> float: ...
	def GetCurve(self) -> False: ...
	def GetDegenerated(self) -> bool: ...
	def GetEdge(self) -> TopoDS_Edge: ...
	@overload
	def GetPCurve(self, theIndex: int) -> False: ...
	def GetSameParam(self) -> bool: ...
	def GetSameRange(self) -> bool: ...
	def IsFree(self) -> bool: ...
	def PCurvesNb(self) -> int: ...
	def SetAngularDeflection(self, theValue: float) -> None: ...
	def SetDegenerated(self, theValue: bool) -> None: ...
	def SetSameParam(self, theValue: bool) -> None: ...
	def SetSameRange(self, theValue: bool) -> None: ...

class IMeshData_Face(IMeshData_TessellatedShape, IMeshData_StatusOwner):
	def AddWire(self, theWire: TopoDS_Wire, theEdgeNb: Optional[int] = 0) -> False: ...
	def GetFace(self) -> TopoDS_Face: ...
	def GetSurface(self) -> BRepAdaptor_HSurface: ...
	def GetWire(self, theIndex: int) -> False: ...
	def IsValid(self) -> bool: ...
	def WiresNb(self) -> int: ...

class IMeshData_Wire(IMeshData_TessellatedShape, IMeshData_StatusOwner):
	def EdgesNb(self) -> int: ...
	def GetEdge(self, theIndex: int) -> False: ...
	def GetEdgeOrientation(self, theIndex: int) -> TopAbs_Orientation: ...
	def GetWire(self) -> TopoDS_Wire: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom2d import *


class TColGeom2d_Array1OfBSplineCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColGeom2d_Array1OfBezierCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColGeom2d_Array1OfCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColGeom2d_SequenceOfBoundedCurve:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColGeom2d_SequenceOfCurve:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColGeom2d_SequenceOfGeometry:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

# harray1 classes

class TColGeom2d_HArray1OfCurve(TColGeom2d_Array1OfCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColGeom2d_Array1OfCurve: ...


class TColGeom2d_HArray1OfBezierCurve(TColGeom2d_Array1OfBezierCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColGeom2d_Array1OfBezierCurve: ...


class TColGeom2d_HArray1OfBSplineCurve(TColGeom2d_Array1OfBSplineCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColGeom2d_Array1OfBSplineCurve: ...

# harray2 classes
# hsequence classes

class TColGeom2d_HSequenceOfBoundedCurve(TColGeom2d_SequenceOfBoundedCurve, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColGeom2d_SequenceOfBoundedCurve) -> None: ...
    def Sequence(self) -> TColGeom2d_SequenceOfBoundedCurve: ...
    def Append(self, theSequence: TColGeom2d_SequenceOfBoundedCurve) -> None: ...


class TColGeom2d_HSequenceOfCurve(TColGeom2d_SequenceOfCurve, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColGeom2d_SequenceOfCurve) -> None: ...
    def Sequence(self) -> TColGeom2d_SequenceOfCurve: ...
    def Append(self, theSequence: TColGeom2d_SequenceOfCurve) -> None: ...





from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepRepr import *
from OCC.Core.TCollection import *
from OCC.Core.StepData import *
from OCC.Core.StepBasic import *
from OCC.Core.StepShape import *


class StepDimTol_Array1OfDatumReference:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepDimTol_Array1OfDatumReferenceCompartment:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepDimTol_Array1OfDatumReferenceElement:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepDimTol_Array1OfDatumReferenceModifier:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepDimTol_DatumReferenceModifier: ...
    def __setitem__(self, index: int, value: StepDimTol_DatumReferenceModifier) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepDimTol_DatumReferenceModifier]: ...
    def next(self) -> StepDimTol_DatumReferenceModifier: ...
    __next__ = next
    def Init(self, theValue: StepDimTol_DatumReferenceModifier) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepDimTol_DatumReferenceModifier: ...
    def Last(self) -> StepDimTol_DatumReferenceModifier: ...
    def Value(self, theIndex: int) -> StepDimTol_DatumReferenceModifier: ...
    def SetValue(self, theIndex: int, theValue: StepDimTol_DatumReferenceModifier) -> None: ...

class StepDimTol_Array1OfDatumSystemOrReference:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepDimTol_DatumSystemOrReference: ...
    def __setitem__(self, index: int, value: StepDimTol_DatumSystemOrReference) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepDimTol_DatumSystemOrReference]: ...
    def next(self) -> StepDimTol_DatumSystemOrReference: ...
    __next__ = next
    def Init(self, theValue: StepDimTol_DatumSystemOrReference) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepDimTol_DatumSystemOrReference: ...
    def Last(self) -> StepDimTol_DatumSystemOrReference: ...
    def Value(self, theIndex: int) -> StepDimTol_DatumSystemOrReference: ...
    def SetValue(self, theIndex: int, theValue: StepDimTol_DatumSystemOrReference) -> None: ...

class StepDimTol_Array1OfGeometricToleranceModifier:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepDimTol_GeometricToleranceModifier: ...
    def __setitem__(self, index: int, value: StepDimTol_GeometricToleranceModifier) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepDimTol_GeometricToleranceModifier]: ...
    def next(self) -> StepDimTol_GeometricToleranceModifier: ...
    __next__ = next
    def Init(self, theValue: StepDimTol_GeometricToleranceModifier) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepDimTol_GeometricToleranceModifier: ...
    def Last(self) -> StepDimTol_GeometricToleranceModifier: ...
    def Value(self, theIndex: int) -> StepDimTol_GeometricToleranceModifier: ...
    def SetValue(self, theIndex: int, theValue: StepDimTol_GeometricToleranceModifier) -> None: ...

class StepDimTol_Array1OfToleranceZoneTarget:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepDimTol_ToleranceZoneTarget: ...
    def __setitem__(self, index: int, value: StepDimTol_ToleranceZoneTarget) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepDimTol_ToleranceZoneTarget]: ...
    def next(self) -> StepDimTol_ToleranceZoneTarget: ...
    __next__ = next
    def Init(self, theValue: StepDimTol_ToleranceZoneTarget) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepDimTol_ToleranceZoneTarget: ...
    def Last(self) -> StepDimTol_ToleranceZoneTarget: ...
    def Value(self, theIndex: int) -> StepDimTol_ToleranceZoneTarget: ...
    def SetValue(self, theIndex: int, theValue: StepDimTol_ToleranceZoneTarget) -> None: ...

class StepDimTol_LimitCondition(IntEnum):
	StepDimTol_MaximumMaterialCondition: int = ...
	StepDimTol_LeastMaterialCondition: int = ...
	StepDimTol_RegardlessOfFeatureSize: int = ...
StepDimTol_MaximumMaterialCondition = StepDimTol_LimitCondition.StepDimTol_MaximumMaterialCondition
StepDimTol_LeastMaterialCondition = StepDimTol_LimitCondition.StepDimTol_LeastMaterialCondition
StepDimTol_RegardlessOfFeatureSize = StepDimTol_LimitCondition.StepDimTol_RegardlessOfFeatureSize

class StepDimTol_GeometricToleranceType(IntEnum):
	StepDimTol_GTTAngularityTolerance: int = ...
	StepDimTol_GTTCircularRunoutTolerance: int = ...
	StepDimTol_GTTCoaxialityTolerance: int = ...
	StepDimTol_GTTConcentricityTolerance: int = ...
	StepDimTol_GTTCylindricityTolerance: int = ...
	StepDimTol_GTTFlatnessTolerance: int = ...
	StepDimTol_GTTLineProfileTolerance: int = ...
	StepDimTol_GTTParallelismTolerance: int = ...
	StepDimTol_GTTPerpendicularityTolerance: int = ...
	StepDimTol_GTTPositionTolerance: int = ...
	StepDimTol_GTTRoundnessTolerance: int = ...
	StepDimTol_GTTStraightnessTolerance: int = ...
	StepDimTol_GTTSurfaceProfileTolerance: int = ...
	StepDimTol_GTTSymmetryTolerance: int = ...
	StepDimTol_GTTTotalRunoutTolerance: int = ...
StepDimTol_GTTAngularityTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTAngularityTolerance
StepDimTol_GTTCircularRunoutTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTCircularRunoutTolerance
StepDimTol_GTTCoaxialityTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTCoaxialityTolerance
StepDimTol_GTTConcentricityTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTConcentricityTolerance
StepDimTol_GTTCylindricityTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTCylindricityTolerance
StepDimTol_GTTFlatnessTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTFlatnessTolerance
StepDimTol_GTTLineProfileTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTLineProfileTolerance
StepDimTol_GTTParallelismTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTParallelismTolerance
StepDimTol_GTTPerpendicularityTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTPerpendicularityTolerance
StepDimTol_GTTPositionTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTPositionTolerance
StepDimTol_GTTRoundnessTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTRoundnessTolerance
StepDimTol_GTTStraightnessTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTStraightnessTolerance
StepDimTol_GTTSurfaceProfileTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTSurfaceProfileTolerance
StepDimTol_GTTSymmetryTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTSymmetryTolerance
StepDimTol_GTTTotalRunoutTolerance = StepDimTol_GeometricToleranceType.StepDimTol_GTTTotalRunoutTolerance

class StepDimTol_DatumReferenceModifierType(IntEnum):
	StepDimTol_CircularOrCylindrical: int = ...
	StepDimTol_Distance: int = ...
	StepDimTol_Projected: int = ...
	StepDimTol_Spherical: int = ...
StepDimTol_CircularOrCylindrical = StepDimTol_DatumReferenceModifierType.StepDimTol_CircularOrCylindrical
StepDimTol_Distance = StepDimTol_DatumReferenceModifierType.StepDimTol_Distance
StepDimTol_Projected = StepDimTol_DatumReferenceModifierType.StepDimTol_Projected
StepDimTol_Spherical = StepDimTol_DatumReferenceModifierType.StepDimTol_Spherical

class StepDimTol_SimpleDatumReferenceModifier(IntEnum):
	StepDimTol_SDRMAnyCrossSection: int = ...
	StepDimTol_SDRMAnyLongitudinalSection: int = ...
	StepDimTol_SDRMBasic: int = ...
	StepDimTol_SDRMContactingFeature: int = ...
	StepDimTol_SDRMDegreeOfFreedomConstraintU: int = ...
	StepDimTol_SDRMDegreeOfFreedomConstraintV: int = ...
	StepDimTol_SDRMDegreeOfFreedomConstraintW: int = ...
	StepDimTol_SDRMDegreeOfFreedomConstraintX: int = ...
	StepDimTol_SDRMDegreeOfFreedomConstraintY: int = ...
	StepDimTol_SDRMDegreeOfFreedomConstraintZ: int = ...
	StepDimTol_SDRMDistanceVariable: int = ...
	StepDimTol_SDRMFreeState: int = ...
	StepDimTol_SDRMLeastMaterialRequirement: int = ...
	StepDimTol_SDRMLine: int = ...
	StepDimTol_SDRMMajorDiameter: int = ...
	StepDimTol_SDRMMaximumMaterialRequirement: int = ...
	StepDimTol_SDRMMinorDiameter: int = ...
	StepDimTol_SDRMOrientation: int = ...
	StepDimTol_SDRMPitchDiameter: int = ...
	StepDimTol_SDRMPlane: int = ...
	StepDimTol_SDRMPoint: int = ...
	StepDimTol_SDRMTranslation: int = ...
StepDimTol_SDRMAnyCrossSection = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMAnyCrossSection
StepDimTol_SDRMAnyLongitudinalSection = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMAnyLongitudinalSection
StepDimTol_SDRMBasic = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMBasic
StepDimTol_SDRMContactingFeature = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMContactingFeature
StepDimTol_SDRMDegreeOfFreedomConstraintU = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMDegreeOfFreedomConstraintU
StepDimTol_SDRMDegreeOfFreedomConstraintV = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMDegreeOfFreedomConstraintV
StepDimTol_SDRMDegreeOfFreedomConstraintW = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMDegreeOfFreedomConstraintW
StepDimTol_SDRMDegreeOfFreedomConstraintX = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMDegreeOfFreedomConstraintX
StepDimTol_SDRMDegreeOfFreedomConstraintY = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMDegreeOfFreedomConstraintY
StepDimTol_SDRMDegreeOfFreedomConstraintZ = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMDegreeOfFreedomConstraintZ
StepDimTol_SDRMDistanceVariable = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMDistanceVariable
StepDimTol_SDRMFreeState = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMFreeState
StepDimTol_SDRMLeastMaterialRequirement = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMLeastMaterialRequirement
StepDimTol_SDRMLine = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMLine
StepDimTol_SDRMMajorDiameter = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMMajorDiameter
StepDimTol_SDRMMaximumMaterialRequirement = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMMaximumMaterialRequirement
StepDimTol_SDRMMinorDiameter = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMMinorDiameter
StepDimTol_SDRMOrientation = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMOrientation
StepDimTol_SDRMPitchDiameter = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMPitchDiameter
StepDimTol_SDRMPlane = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMPlane
StepDimTol_SDRMPoint = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMPoint
StepDimTol_SDRMTranslation = StepDimTol_SimpleDatumReferenceModifier.StepDimTol_SDRMTranslation

class StepDimTol_AreaUnitType(IntEnum):
	StepDimTol_Circular: int = ...
	StepDimTol_Rectangular: int = ...
	StepDimTol_Square: int = ...
StepDimTol_Circular = StepDimTol_AreaUnitType.StepDimTol_Circular
StepDimTol_Rectangular = StepDimTol_AreaUnitType.StepDimTol_Rectangular
StepDimTol_Square = StepDimTol_AreaUnitType.StepDimTol_Square

class StepDimTol_GeometricToleranceModifier(IntEnum):
	StepDimTol_GTMAnyCrossSection: int = ...
	StepDimTol_GTMCommonZone: int = ...
	StepDimTol_GTMEachRadialElement: int = ...
	StepDimTol_GTMFreeState: int = ...
	StepDimTol_GTMLeastMaterialRequirement: int = ...
	StepDimTol_GTMLineElement: int = ...
	StepDimTol_GTMMajorDiameter: int = ...
	StepDimTol_GTMMaximumMaterialRequirement: int = ...
	StepDimTol_GTMMinorDiameter: int = ...
	StepDimTol_GTMNotConvex: int = ...
	StepDimTol_GTMPitchDiameter: int = ...
	StepDimTol_GTMReciprocityRequirement: int = ...
	StepDimTol_GTMSeparateRequirement: int = ...
	StepDimTol_GTMStatisticalTolerance: int = ...
	StepDimTol_GTMTangentPlane: int = ...
StepDimTol_GTMAnyCrossSection = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMAnyCrossSection
StepDimTol_GTMCommonZone = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMCommonZone
StepDimTol_GTMEachRadialElement = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMEachRadialElement
StepDimTol_GTMFreeState = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMFreeState
StepDimTol_GTMLeastMaterialRequirement = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMLeastMaterialRequirement
StepDimTol_GTMLineElement = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMLineElement
StepDimTol_GTMMajorDiameter = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMMajorDiameter
StepDimTol_GTMMaximumMaterialRequirement = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMMaximumMaterialRequirement
StepDimTol_GTMMinorDiameter = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMMinorDiameter
StepDimTol_GTMNotConvex = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMNotConvex
StepDimTol_GTMPitchDiameter = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMPitchDiameter
StepDimTol_GTMReciprocityRequirement = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMReciprocityRequirement
StepDimTol_GTMSeparateRequirement = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMSeparateRequirement
StepDimTol_GTMStatisticalTolerance = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMStatisticalTolerance
StepDimTol_GTMTangentPlane = StepDimTol_GeometricToleranceModifier.StepDimTol_GTMTangentPlane

class StepDimTol_CommonDatum(StepRepr_CompositeShapeAspect):
	def __init__(self) -> None: ...
	def Datum(self) -> StepDimTol_Datum: ...
	def Init(self, theShapeAspect_Name: TCollection_HAsciiString, theShapeAspect_Description: TCollection_HAsciiString, theShapeAspect_OfShape: StepRepr_ProductDefinitionShape, theShapeAspect_ProductDefinitional: StepData_Logical, theDatum_Name: TCollection_HAsciiString, theDatum_Description: TCollection_HAsciiString, theDatum_OfShape: StepRepr_ProductDefinitionShape, theDatum_ProductDefinitional: StepData_Logical, theDatum_Identification: TCollection_HAsciiString) -> None: ...
	def SetDatum(self, theDatum: StepDimTol_Datum) -> None: ...

class StepDimTol_Datum(StepRepr_ShapeAspect):
	def __init__(self) -> None: ...
	def Identification(self) -> TCollection_HAsciiString: ...
	def Init(self, theShapeAspect_Name: TCollection_HAsciiString, theShapeAspect_Description: TCollection_HAsciiString, theShapeAspect_OfShape: StepRepr_ProductDefinitionShape, theShapeAspect_ProductDefinitional: StepData_Logical, theIdentification: TCollection_HAsciiString) -> None: ...
	def SetIdentification(self, theIdentification: TCollection_HAsciiString) -> None: ...

class StepDimTol_DatumFeature(StepRepr_ShapeAspect):
	def __init__(self) -> None: ...

class StepDimTol_DatumOrCommonDatum(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def CommonDatumList(self) -> StepDimTol_HArray1OfDatumReferenceElement: ...
	def Datum(self) -> StepDimTol_Datum: ...

class StepDimTol_DatumReference(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, thePrecedence: int, theReferencedDatum: StepDimTol_Datum) -> None: ...
	def Precedence(self) -> int: ...
	def ReferencedDatum(self) -> StepDimTol_Datum: ...
	def SetPrecedence(self, thePrecedence: int) -> None: ...
	def SetReferencedDatum(self, theReferencedDatum: StepDimTol_Datum) -> None: ...

class StepDimTol_DatumReferenceModifier(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DatumReferenceModifierWithValue(self) -> StepDimTol_DatumReferenceModifierWithValue: ...
	def SimpleDatumReferenceModifierMember(self) -> StepDimTol_SimpleDatumReferenceModifierMember: ...

class StepDimTol_DatumReferenceModifierWithValue(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, theModifierType: StepDimTol_DatumReferenceModifierType, theModifierValue: StepBasic_LengthMeasureWithUnit) -> None: ...
	def ModifierType(self) -> StepDimTol_DatumReferenceModifierType: ...
	def ModifierValue(self) -> StepBasic_LengthMeasureWithUnit: ...
	def SetModifierType(self, theModifierType: StepDimTol_DatumReferenceModifierType) -> None: ...
	def SetModifierValue(self, theModifierValue: StepBasic_LengthMeasureWithUnit) -> None: ...

class StepDimTol_DatumSystem(StepRepr_ShapeAspect):
	def __init__(self) -> None: ...
	def Constituents(self) -> StepDimTol_HArray1OfDatumReferenceCompartment: ...
	@overload
	def ConstituentsValue(self, num: int) -> StepDimTol_DatumReferenceCompartment: ...
	@overload
	def ConstituentsValue(self, num: int, theItem: StepDimTol_DatumReferenceCompartment) -> None: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theOfShape: StepRepr_ProductDefinitionShape, theProductDefinitional: StepData_Logical, theConstituents: StepDimTol_HArray1OfDatumReferenceCompartment) -> None: ...
	def NbConstituents(self) -> int: ...
	def SetConstituents(self, theConstituents: StepDimTol_HArray1OfDatumReferenceCompartment) -> None: ...

class StepDimTol_DatumSystemOrReference(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DatumReference(self) -> StepDimTol_DatumReference: ...
	def DatumSystem(self) -> StepDimTol_DatumSystem: ...

class StepDimTol_DatumTarget(StepRepr_ShapeAspect):
	def __init__(self) -> None: ...
	def Init(self, theShapeAspect_Name: TCollection_HAsciiString, theShapeAspect_Description: TCollection_HAsciiString, theShapeAspect_OfShape: StepRepr_ProductDefinitionShape, theShapeAspect_ProductDefinitional: StepData_Logical, theTargetId: TCollection_HAsciiString) -> None: ...
	def SetTargetId(self, theTargetId: TCollection_HAsciiString) -> None: ...
	def TargetId(self) -> TCollection_HAsciiString: ...

class StepDimTol_GeneralDatumReference(StepRepr_ShapeAspect):
	def __init__(self) -> None: ...
	def Base(self) -> StepDimTol_DatumOrCommonDatum: ...
	def HasModifiers(self) -> bool: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theOfShape: StepRepr_ProductDefinitionShape, theProductDefinitional: StepData_Logical, theBase: StepDimTol_DatumOrCommonDatum, theHasModifiers: bool, theModifiers: StepDimTol_HArray1OfDatumReferenceModifier) -> None: ...
	def Modifiers(self) -> StepDimTol_HArray1OfDatumReferenceModifier: ...
	@overload
	def ModifiersValue(self, theNum: int) -> StepDimTol_DatumReferenceModifier: ...
	@overload
	def ModifiersValue(self, theNum: int, theItem: StepDimTol_DatumReferenceModifier) -> None: ...
	def NbModifiers(self) -> int: ...
	def SetBase(self, theBase: StepDimTol_DatumOrCommonDatum) -> None: ...
	def SetModifiers(self, theModifiers: StepDimTol_HArray1OfDatumReferenceModifier) -> None: ...

class StepDimTol_GeometricTolerance(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect) -> None: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget) -> None: ...
	def Magnitude(self) -> StepBasic_MeasureWithUnit: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def SetDescription(self, theDescription: TCollection_HAsciiString) -> None: ...
	def SetMagnitude(self, theMagnitude: StepBasic_MeasureWithUnit) -> None: ...
	def SetName(self, theName: TCollection_HAsciiString) -> None: ...
	@overload
	def SetTolerancedShapeAspect(self, theTolerancedShapeAspect: StepRepr_ShapeAspect) -> None: ...
	@overload
	def SetTolerancedShapeAspect(self, theTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget) -> None: ...
	def TolerancedShapeAspect(self) -> StepDimTol_GeometricToleranceTarget: ...

class StepDimTol_GeometricToleranceRelationship(Standard_Transient):
	def __init__(self) -> None: ...
	def Description(self) -> TCollection_HAsciiString: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theRelatingGeometricTolerance: StepDimTol_GeometricTolerance, theRelatedGeometricTolerance: StepDimTol_GeometricTolerance) -> None: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def RelatedGeometricTolerance(self) -> StepDimTol_GeometricTolerance: ...
	def RelatingGeometricTolerance(self) -> StepDimTol_GeometricTolerance: ...
	def SetDescription(self, theDescription: TCollection_HAsciiString) -> None: ...
	def SetName(self, theName: TCollection_HAsciiString) -> None: ...
	def SetRelatedGeometricTolerance(self, theRelatedGeometricTolerance: StepDimTol_GeometricTolerance) -> None: ...
	def SetRelatingGeometricTolerance(self, theRelatingGeometricTolerance: StepDimTol_GeometricTolerance) -> None: ...

class StepDimTol_GeometricToleranceTarget(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DimensionalLocation(self) -> StepShape_DimensionalLocation: ...
	def DimensionalSize(self) -> StepShape_DimensionalSize: ...
	def ProductDefinitionShape(self) -> StepRepr_ProductDefinitionShape: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...

class StepDimTol_RunoutZoneOrientation(Standard_Transient):
	def __init__(self) -> None: ...
	def Angle(self) -> StepBasic_PlaneAngleMeasureWithUnit: ...
	def Init(self, theAngle: StepBasic_PlaneAngleMeasureWithUnit) -> None: ...
	def SetAngle(self, theAngle: StepBasic_PlaneAngleMeasureWithUnit) -> None: ...

class StepDimTol_ShapeToleranceSelect(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def GeometricTolerance(self) -> StepDimTol_GeometricTolerance: ...
	def PlusMinusTolerance(self) -> StepShape_PlusMinusTolerance: ...

class StepDimTol_SimpleDatumReferenceModifierMember(StepData_SelectInt):
	def __init__(self) -> None: ...
	def EnumText(self) -> str: ...
	def HasName(self) -> bool: ...
	def Kind(self) -> int: ...
	def Name(self) -> str: ...
	def SetEnumText(self, theValue: int, theText: str) -> None: ...
	def SetValue(self, theValue: StepDimTol_SimpleDatumReferenceModifier) -> None: ...
	def Value(self) -> StepDimTol_SimpleDatumReferenceModifier: ...

class StepDimTol_ToleranceZone(StepRepr_ShapeAspect):
	def __init__(self) -> None: ...
	def DefiningTolerance(self) -> StepDimTol_HArray1OfToleranceZoneTarget: ...
	def DefiningToleranceValue(self, theNum: int) -> StepDimTol_ToleranceZoneTarget: ...
	def Form(self) -> StepDimTol_ToleranceZoneForm: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theOfShape: StepRepr_ProductDefinitionShape, theProductDefinitional: StepData_Logical, theDefiningTolerance: StepDimTol_HArray1OfToleranceZoneTarget, theForm: StepDimTol_ToleranceZoneForm) -> None: ...
	def NbDefiningTolerances(self) -> int: ...
	def SetDefiningTolerance(self, theDefiningTolerance: StepDimTol_HArray1OfToleranceZoneTarget) -> None: ...
	def SetDefiningToleranceValue(self, theNum: int, theItem: StepDimTol_ToleranceZoneTarget) -> None: ...
	def SetForm(self, theForm: StepDimTol_ToleranceZoneForm) -> None: ...

class StepDimTol_ToleranceZoneDefinition(Standard_Transient):
	def __init__(self) -> None: ...
	def Boundaries(self) -> StepRepr_HArray1OfShapeAspect: ...
	def BoundariesValue(self, theNum: int) -> StepRepr_ShapeAspect: ...
	def Init(self, theZone: StepDimTol_ToleranceZone, theBoundaries: StepRepr_HArray1OfShapeAspect) -> None: ...
	def NbBoundaries(self) -> int: ...
	def SetBoundaries(self, theBoundaries: StepRepr_HArray1OfShapeAspect) -> None: ...
	def SetBoundariesValue(self, theNum: int, theItem: StepRepr_ShapeAspect) -> None: ...
	def SetZone(self, theZone: StepDimTol_ToleranceZone) -> None: ...
	def Zone(self) -> StepDimTol_ToleranceZone: ...

class StepDimTol_ToleranceZoneForm(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, theName: TCollection_HAsciiString) -> None: ...
	def Name(self) -> TCollection_HAsciiString: ...
	def SetName(self, theName: TCollection_HAsciiString) -> None: ...

class StepDimTol_ToleranceZoneTarget(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DimensionalLocation(self) -> StepShape_DimensionalLocation: ...
	def DimensionalSize(self) -> StepShape_DimensionalSize: ...
	def GeneralDatumReference(self) -> StepDimTol_GeneralDatumReference: ...
	def GeometricTolerance(self) -> StepDimTol_GeometricTolerance: ...

class StepDimTol_CylindricityTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...

class StepDimTol_DatumReferenceCompartment(StepDimTol_GeneralDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_DatumReferenceElement(StepDimTol_GeneralDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_FlatnessTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...

class StepDimTol_GeoTolAndGeoTolWthDatRef(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	def GetGeometricToleranceWithDatumReference(self) -> StepDimTol_GeometricToleranceWithDatumReference: ...
	def GetToleranceType(self) -> StepDimTol_GeometricToleranceType: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect, theGTWDR: StepDimTol_GeometricToleranceWithDatumReference, theType: StepDimTol_GeometricToleranceType) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, aGTWDR: StepDimTol_GeometricToleranceWithDatumReference, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetGeometricToleranceType(self, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetGeometricToleranceWithDatumReference(self, theGTWDR: StepDimTol_GeometricToleranceWithDatumReference) -> None: ...

class StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMod(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	def GetGeometricToleranceWithDatumReference(self) -> StepDimTol_GeometricToleranceWithDatumReference: ...
	def GetGeometricToleranceWithModifiers(self) -> StepDimTol_GeometricToleranceWithModifiers: ...
	def GetToleranceType(self) -> StepDimTol_GeometricToleranceType: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect, theGTWDR: StepDimTol_GeometricToleranceWithDatumReference, theGTWM: StepDimTol_GeometricToleranceWithModifiers, theType: StepDimTol_GeometricToleranceType) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, aGTWDR: StepDimTol_GeometricToleranceWithDatumReference, aGTWM: StepDimTol_GeometricToleranceWithModifiers, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetGeometricToleranceType(self, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetGeometricToleranceWithDatumReference(self, theGTWDR: StepDimTol_GeometricToleranceWithDatumReference) -> None: ...
	def SetGeometricToleranceWithModifiers(self, theGTWM: StepDimTol_GeometricToleranceWithModifiers) -> None: ...

class StepDimTol_GeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	def GetGeometricToleranceWithDatumReference(self) -> StepDimTol_GeometricToleranceWithDatumReference: ...
	def GetModifiedGeometricTolerance(self) -> StepDimTol_ModifiedGeometricTolerance: ...
	def GetPositionTolerance(self) -> StepDimTol_PositionTolerance: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepRepr_ShapeAspect, aGTWDR: StepDimTol_GeometricToleranceWithDatumReference, aMGT: StepDimTol_ModifiedGeometricTolerance) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, aGTWDR: StepDimTol_GeometricToleranceWithDatumReference, aMGT: StepDimTol_ModifiedGeometricTolerance) -> None: ...
	def SetGeometricToleranceWithDatumReference(self, aGTWDR: StepDimTol_GeometricToleranceWithDatumReference) -> None: ...
	def SetModifiedGeometricTolerance(self, aMGT: StepDimTol_ModifiedGeometricTolerance) -> None: ...
	def SetPositionTolerance(self, aPT: StepDimTol_PositionTolerance) -> None: ...

class StepDimTol_GeoTolAndGeoTolWthMod(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	def GetGeometricToleranceWithModifiers(self) -> StepDimTol_GeometricToleranceWithModifiers: ...
	def GetToleranceType(self) -> StepDimTol_GeometricToleranceType: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect, theGTWM: StepDimTol_GeometricToleranceWithModifiers, theType: StepDimTol_GeometricToleranceType) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, aGTWM: StepDimTol_GeometricToleranceWithModifiers, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetGeometricToleranceType(self, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetGeometricToleranceWithModifiers(self, theGTWM: StepDimTol_GeometricToleranceWithModifiers) -> None: ...

class StepDimTol_GeometricToleranceWithDatumReference(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	def DatumSystem(self) -> StepDimTol_HArray1OfDatumReference: ...
	def DatumSystemAP242(self) -> StepDimTol_HArray1OfDatumSystemOrReference: ...
	@overload
	def Init(self, theGeometricTolerance_Name: TCollection_HAsciiString, theGeometricTolerance_Description: TCollection_HAsciiString, theGeometricTolerance_Magnitude: StepBasic_MeasureWithUnit, theGeometricTolerance_TolerancedShapeAspect: StepRepr_ShapeAspect, theDatumSystem: StepDimTol_HArray1OfDatumReference) -> None: ...
	@overload
	def Init(self, theGeometricTolerance_Name: TCollection_HAsciiString, theGeometricTolerance_Description: TCollection_HAsciiString, theGeometricTolerance_Magnitude: StepBasic_MeasureWithUnit, theGeometricTolerance_TolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, theDatumSystem: StepDimTol_HArray1OfDatumSystemOrReference) -> None: ...
	@overload
	def SetDatumSystem(self, theDatumSystem: StepDimTol_HArray1OfDatumReference) -> None: ...
	@overload
	def SetDatumSystem(self, theDatumSystem: StepDimTol_HArray1OfDatumSystemOrReference) -> None: ...

class StepDimTol_GeometricToleranceWithDefinedUnit(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect, theUnitSize: StepBasic_LengthMeasureWithUnit) -> None: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, theUnitSize: StepBasic_LengthMeasureWithUnit) -> None: ...
	def SetUnitSize(self, theUnitSize: StepBasic_LengthMeasureWithUnit) -> None: ...
	def UnitSize(self) -> StepBasic_LengthMeasureWithUnit: ...

class StepDimTol_GeometricToleranceWithModifiers(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, theModifiers: StepDimTol_HArray1OfGeometricToleranceModifier) -> None: ...
	def ModifierValue(self, theNum: int) -> StepDimTol_GeometricToleranceModifier: ...
	def Modifiers(self) -> StepDimTol_HArray1OfGeometricToleranceModifier: ...
	def NbModifiers(self) -> int: ...
	def SetModifierValue(self, theNum: int, theItem: StepDimTol_GeometricToleranceModifier) -> None: ...
	def SetModifiers(self, theModifiers: StepDimTol_HArray1OfGeometricToleranceModifier) -> None: ...

class StepDimTol_LineProfileTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...

class StepDimTol_ModifiedGeometricTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	@overload
	def Init(self, theGeometricTolerance_Name: TCollection_HAsciiString, theGeometricTolerance_Description: TCollection_HAsciiString, theGeometricTolerance_Magnitude: StepBasic_MeasureWithUnit, theGeometricTolerance_TolerancedShapeAspect: StepRepr_ShapeAspect, theModifier: StepDimTol_LimitCondition) -> None: ...
	@overload
	def Init(self, theGeometricTolerance_Name: TCollection_HAsciiString, theGeometricTolerance_Description: TCollection_HAsciiString, theGeometricTolerance_Magnitude: StepBasic_MeasureWithUnit, theGeometricTolerance_TolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, theModifier: StepDimTol_LimitCondition) -> None: ...
	def Modifier(self) -> StepDimTol_LimitCondition: ...
	def SetModifier(self, theModifier: StepDimTol_LimitCondition) -> None: ...

class StepDimTol_NonUniformZoneDefinition(StepDimTol_ToleranceZoneDefinition):
	def __init__(self) -> None: ...

class StepDimTol_PlacedDatumTargetFeature(StepDimTol_DatumTarget):
	def __init__(self) -> None: ...

class StepDimTol_PositionTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...

class StepDimTol_ProjectedZoneDefinition(StepDimTol_ToleranceZoneDefinition):
	def __init__(self) -> None: ...
	def Init(self, theZone: StepDimTol_ToleranceZone, theBoundaries: StepRepr_HArray1OfShapeAspect, theProjectionEnd: StepRepr_ShapeAspect, theProjectionLength: StepBasic_LengthMeasureWithUnit) -> None: ...
	def ProjectionEnd(self) -> StepRepr_ShapeAspect: ...
	def ProjectionLength(self) -> StepBasic_LengthMeasureWithUnit: ...
	def SetProjectionEnd(self, theProjectionEnd: StepRepr_ShapeAspect) -> None: ...
	def SetProjectionLength(self, theProjectionLength: StepBasic_LengthMeasureWithUnit) -> None: ...

class StepDimTol_RoundnessTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...

class StepDimTol_RunoutZoneDefinition(StepDimTol_ToleranceZoneDefinition):
	def __init__(self) -> None: ...
	def Init(self, theZone: StepDimTol_ToleranceZone, theBoundaries: StepRepr_HArray1OfShapeAspect, theOrientation: StepDimTol_RunoutZoneOrientation) -> None: ...
	def Orientation(self) -> StepDimTol_RunoutZoneOrientation: ...
	def SetOrientation(self, theOrientation: StepDimTol_RunoutZoneOrientation) -> None: ...

class StepDimTol_StraightnessTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...

class StepDimTol_SurfaceProfileTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...

class StepDimTol_UnequallyDisposedGeometricTolerance(StepDimTol_GeometricTolerance):
	def __init__(self) -> None: ...
	def Displacement(self) -> StepBasic_LengthMeasureWithUnit: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, theDisplacement: StepBasic_LengthMeasureWithUnit) -> None: ...
	def SetDisplacement(self, theDisplacement: StepBasic_LengthMeasureWithUnit) -> None: ...

class StepDimTol_AngularityTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_CircularRunoutTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_CoaxialityTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_ConcentricityTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol(StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMod):
	def __init__(self) -> None: ...
	def GetMaxTolerance(self) -> StepBasic_LengthMeasureWithUnit: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect, theGTWDR: StepDimTol_GeometricToleranceWithDatumReference, theGTWM: StepDimTol_GeometricToleranceWithModifiers, theMaxTol: StepBasic_LengthMeasureWithUnit, theType: StepDimTol_GeometricToleranceType) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, aGTWDR: StepDimTol_GeometricToleranceWithDatumReference, aGTWM: StepDimTol_GeometricToleranceWithModifiers, theMaxTol: StepBasic_LengthMeasureWithUnit, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetMaxTolerance(self, theMaxTol: StepBasic_LengthMeasureWithUnit) -> None: ...

class StepDimTol_GeoTolAndGeoTolWthDatRefAndUneqDisGeoTol(StepDimTol_GeoTolAndGeoTolWthDatRef):
	def __init__(self) -> None: ...
	def GetUnequallyDisposedGeometricTolerance(self) -> StepDimTol_UnequallyDisposedGeometricTolerance: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect, theGTWDR: StepDimTol_GeometricToleranceWithDatumReference, theType: StepDimTol_GeometricToleranceType, theUDGT: StepDimTol_UnequallyDisposedGeometricTolerance) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, aGTWDR: StepDimTol_GeometricToleranceWithDatumReference, theType: StepDimTol_GeometricToleranceType, theUDGT: StepDimTol_UnequallyDisposedGeometricTolerance) -> None: ...
	def SetUnequallyDisposedGeometricTolerance(self, theUDGT: StepDimTol_UnequallyDisposedGeometricTolerance) -> None: ...

class StepDimTol_GeoTolAndGeoTolWthMaxTol(StepDimTol_GeoTolAndGeoTolWthMod):
	def __init__(self) -> None: ...
	def GetMaxTolerance(self) -> StepBasic_LengthMeasureWithUnit: ...
	@overload
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepRepr_ShapeAspect, theGTWM: StepDimTol_GeometricToleranceWithModifiers, theMaxTol: StepBasic_LengthMeasureWithUnit, theType: StepDimTol_GeometricToleranceType) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDescription: TCollection_HAsciiString, aMagnitude: StepBasic_MeasureWithUnit, aTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, aGTWM: StepDimTol_GeometricToleranceWithModifiers, theMaxTol: StepBasic_LengthMeasureWithUnit, theType: StepDimTol_GeometricToleranceType) -> None: ...
	def SetMaxTolerance(self, theMaxTol: StepBasic_LengthMeasureWithUnit) -> None: ...

class StepDimTol_GeometricToleranceWithDefinedAreaUnit(StepDimTol_GeometricToleranceWithDefinedUnit):
	def __init__(self) -> None: ...
	def AreaType(self) -> StepDimTol_AreaUnitType: ...
	def HasSecondUnitSize(self) -> bool: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, theUnitSize: StepBasic_LengthMeasureWithUnit, theAreaType: StepDimTol_AreaUnitType, theHasSecondUnitSize: bool, theSecondUnitSize: StepBasic_LengthMeasureWithUnit) -> None: ...
	def SecondUnitSize(self) -> StepBasic_LengthMeasureWithUnit: ...
	def SetAreaType(self, theAreaType: StepDimTol_AreaUnitType) -> None: ...
	def SetSecondUnitSize(self, theSecondUnitSize: StepBasic_LengthMeasureWithUnit) -> None: ...

class StepDimTol_GeometricToleranceWithMaximumTolerance(StepDimTol_GeometricToleranceWithModifiers):
	def __init__(self) -> None: ...
	def Init(self, theName: TCollection_HAsciiString, theDescription: TCollection_HAsciiString, theMagnitude: StepBasic_MeasureWithUnit, theTolerancedShapeAspect: StepDimTol_GeometricToleranceTarget, theModifiers: StepDimTol_HArray1OfGeometricToleranceModifier, theUnitSize: StepBasic_LengthMeasureWithUnit) -> None: ...
	def MaximumUpperTolerance(self) -> StepBasic_LengthMeasureWithUnit: ...
	def SetMaximumUpperTolerance(self, theMaximumUpperTolerance: StepBasic_LengthMeasureWithUnit) -> None: ...

class StepDimTol_ParallelismTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_PerpendicularityTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_SymmetryTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

class StepDimTol_TotalRunoutTolerance(StepDimTol_GeometricToleranceWithDatumReference):
	def __init__(self) -> None: ...

# harray1 classes

class StepDimTol_HArray1OfToleranceZoneTarget(StepDimTol_Array1OfToleranceZoneTarget, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepDimTol_Array1OfToleranceZoneTarget: ...


class StepDimTol_HArray1OfDatumReference(StepDimTol_Array1OfDatumReference, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepDimTol_Array1OfDatumReference: ...


class StepDimTol_HArray1OfDatumReferenceElement(StepDimTol_Array1OfDatumReferenceElement, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepDimTol_Array1OfDatumReferenceElement: ...


class StepDimTol_HArray1OfDatumSystemOrReference(StepDimTol_Array1OfDatumSystemOrReference, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepDimTol_Array1OfDatumSystemOrReference: ...


class StepDimTol_HArray1OfDatumReferenceCompartment(StepDimTol_Array1OfDatumReferenceCompartment, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepDimTol_Array1OfDatumReferenceCompartment: ...


class StepDimTol_HArray1OfDatumReferenceModifier(StepDimTol_Array1OfDatumReferenceModifier, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepDimTol_Array1OfDatumReferenceModifier: ...


class StepDimTol_HArray1OfGeometricToleranceModifier(StepDimTol_Array1OfGeometricToleranceModifier, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepDimTol_Array1OfGeometricToleranceModifier: ...

# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TDF import *
from OCC.Core.Quantity import *
from OCC.Core.AIS import *
from OCC.Core.Graphic3d import *
from OCC.Core.V3d import *
from OCC.Core.TDataXtd import *
from OCC.Core.TCollection import *


class TPrsStd_AISPresentation(TDF_Attribute):
	def __init__(self) -> None: ...
	def AddSelectionMode(self, theSelectionMode: int, theTransaction: Optional[bool] = True) -> None: ...
	def AfterAddition(self) -> None: ...
	def AfterResume(self) -> None: ...
	def AfterUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def BackupCopy(self) -> TDF_Attribute: ...
	def BeforeForget(self) -> None: ...
	def BeforeRemoval(self) -> None: ...
	def BeforeUndo(self, anAttDelta: TDF_AttributeDelta, forceIt: Optional[bool] = False) -> bool: ...
	def Color(self) -> Quantity_NameOfColor: ...
	def Display(self, update: Optional[bool] = False) -> None: ...
	def Erase(self, remove: Optional[bool] = False) -> None: ...
	def GetAIS(self) -> AIS_InteractiveObject: ...
	def GetDriverGUID(self) -> Standard_GUID: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetNbSelectionModes(self) -> int: ...
	def HasOwnColor(self) -> bool: ...
	def HasOwnMaterial(self) -> bool: ...
	def HasOwnMode(self) -> bool: ...
	def HasOwnSelectionMode(self) -> bool: ...
	def HasOwnTransparency(self) -> bool: ...
	def HasOwnWidth(self) -> bool: ...
	def ID(self) -> Standard_GUID: ...
	def IsDisplayed(self) -> bool: ...
	def Material(self) -> Graphic3d_NameOfMaterial: ...
	def Mode(self) -> int: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	def SelectionMode(self, index: Optional[int] = 1) -> int: ...
	@overload
	@staticmethod
	def Set(L: TDF_Label, driver: Standard_GUID) -> TPrsStd_AISPresentation: ...
	@overload
	@staticmethod
	def Set(master: TDF_Attribute) -> TPrsStd_AISPresentation: ...
	def SetColor(self, aColor: Quantity_NameOfColor) -> None: ...
	def SetDisplayed(self, B: bool) -> None: ...
	def SetDriverGUID(self, guid: Standard_GUID) -> None: ...
	def SetMaterial(self, aName: Graphic3d_NameOfMaterial) -> None: ...
	def SetMode(self, theMode: int) -> None: ...
	def SetSelectionMode(self, theSelectionMode: int, theTransaction: Optional[bool] = True) -> None: ...
	def SetTransparency(self, aValue: Optional[float] = 0.6) -> None: ...
	def SetWidth(self, aWidth: float) -> None: ...
	def Transparency(self) -> float: ...
	@staticmethod
	def Unset(L: TDF_Label) -> None: ...
	def UnsetColor(self) -> None: ...
	def UnsetMaterial(self) -> None: ...
	def UnsetMode(self) -> None: ...
	def UnsetSelectionMode(self) -> None: ...
	def UnsetTransparency(self) -> None: ...
	def UnsetWidth(self) -> None: ...
	def Update(self) -> None: ...
	def Width(self) -> float: ...

class TPrsStd_AISViewer(TDF_Attribute):
	def __init__(self) -> None: ...
	@overload
	@staticmethod
	def Find(acces: TDF_Label, A: TPrsStd_AISViewer) -> bool: ...
	@overload
	@staticmethod
	def Find(acces: TDF_Label, IC: AIS_InteractiveContext) -> bool: ...
	@overload
	@staticmethod
	def Find(acces: TDF_Label, V: V3d_Viewer) -> bool: ...
	@staticmethod
	def GetID() -> Standard_GUID: ...
	def GetInteractiveContext(self) -> AIS_InteractiveContext: ...
	@staticmethod
	def Has(acces: TDF_Label) -> bool: ...
	def ID(self) -> Standard_GUID: ...
	@overload
	@staticmethod
	def New(access: TDF_Label, selector: AIS_InteractiveContext) -> TPrsStd_AISViewer: ...
	@overload
	@staticmethod
	def New(acces: TDF_Label, viewer: V3d_Viewer) -> TPrsStd_AISViewer: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	def Paste(self, into: TDF_Attribute, RT: TDF_RelocationTable) -> None: ...
	def Restore(self, with_: TDF_Attribute) -> None: ...
	def SetInteractiveContext(self, ctx: AIS_InteractiveContext) -> None: ...
	@overload
	@staticmethod
	def Update(acces: TDF_Label) -> None: ...
	@overload
	def Update(self) -> None: ...

class TPrsStd_ConstraintTools:
	@staticmethod
	def ComputeAngle(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeAngleForOneFace(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeCoincident(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeConcentric(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeDiameter(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeDistance(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeEqualDistance(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeEqualRadius(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeFix(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeMaxRadius(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeMidPoint(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeMinRadius(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeOffset(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeOthers(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeParallel(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputePerpendicular(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputePlacement(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeRadius(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeRound(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeSymmetry(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeTangent(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...
	@staticmethod
	def ComputeTextAndValue(aConst: TDataXtd_Constraint, aText: TCollection_ExtendedString, anIsAngle: bool) -> float: ...
	@staticmethod
	def UpdateOnlyValue(aConst: TDataXtd_Constraint, anAIS: AIS_InteractiveObject) -> None: ...

class TPrsStd_Driver(Standard_Transient):
	def Update(self, L: TDF_Label, ais: AIS_InteractiveObject) -> bool: ...

class TPrsStd_DriverTable(Standard_Transient):
	def __init__(self) -> None: ...
	def AddDriver(self, guid: Standard_GUID, driver: TPrsStd_Driver) -> bool: ...
	def Clear(self) -> None: ...
	def FindDriver(self, guid: Standard_GUID, driver: TPrsStd_Driver) -> bool: ...
	@staticmethod
	def Get() -> TPrsStd_DriverTable: ...
	def InitStandardDrivers(self) -> None: ...
	def RemoveDriver(self, guid: Standard_GUID) -> bool: ...

class TPrsStd_AxisDriver(TPrsStd_Driver):
	def __init__(self) -> None: ...
	def Update(self, aLabel: TDF_Label, anAISObject: AIS_InteractiveObject) -> bool: ...

class TPrsStd_ConstraintDriver(TPrsStd_Driver):
	def __init__(self) -> None: ...
	def Update(self, aLabel: TDF_Label, anAISObject: AIS_InteractiveObject) -> bool: ...

class TPrsStd_GeometryDriver(TPrsStd_Driver):
	def __init__(self) -> None: ...
	def Update(self, aLabel: TDF_Label, anAISObject: AIS_InteractiveObject) -> bool: ...

class TPrsStd_NamedShapeDriver(TPrsStd_Driver):
	def __init__(self) -> None: ...
	def Update(self, aLabel: TDF_Label, anAISObject: AIS_InteractiveObject) -> bool: ...

class TPrsStd_PlaneDriver(TPrsStd_Driver):
	def __init__(self) -> None: ...
	def Update(self, aLabel: TDF_Label, anAISObject: AIS_InteractiveObject) -> bool: ...

class TPrsStd_PointDriver(TPrsStd_Driver):
	def __init__(self) -> None: ...
	def Update(self, aLabel: TDF_Label, anAISObject: AIS_InteractiveObject) -> bool: ...

# harray1 classes
# harray2 classes
# hsequence classes

TPrsStd_AISPresentation_GetID = TPrsStd_AISPresentation.GetID
TPrsStd_AISPresentation_Set = TPrsStd_AISPresentation.Set
TPrsStd_AISPresentation_Set = TPrsStd_AISPresentation.Set
TPrsStd_AISPresentation_Unset = TPrsStd_AISPresentation.Unset
TPrsStd_AISViewer_Find = TPrsStd_AISViewer.Find
TPrsStd_AISViewer_Find = TPrsStd_AISViewer.Find
TPrsStd_AISViewer_Find = TPrsStd_AISViewer.Find
TPrsStd_AISViewer_GetID = TPrsStd_AISViewer.GetID
TPrsStd_AISViewer_Has = TPrsStd_AISViewer.Has
TPrsStd_AISViewer_New = TPrsStd_AISViewer.New
TPrsStd_AISViewer_New = TPrsStd_AISViewer.New
TPrsStd_AISViewer_Update = TPrsStd_AISViewer.Update
TPrsStd_ConstraintTools_ComputeAngle = TPrsStd_ConstraintTools.ComputeAngle
TPrsStd_ConstraintTools_ComputeAngleForOneFace = TPrsStd_ConstraintTools.ComputeAngleForOneFace
TPrsStd_ConstraintTools_ComputeCoincident = TPrsStd_ConstraintTools.ComputeCoincident
TPrsStd_ConstraintTools_ComputeConcentric = TPrsStd_ConstraintTools.ComputeConcentric
TPrsStd_ConstraintTools_ComputeDiameter = TPrsStd_ConstraintTools.ComputeDiameter
TPrsStd_ConstraintTools_ComputeDistance = TPrsStd_ConstraintTools.ComputeDistance
TPrsStd_ConstraintTools_ComputeEqualDistance = TPrsStd_ConstraintTools.ComputeEqualDistance
TPrsStd_ConstraintTools_ComputeEqualRadius = TPrsStd_ConstraintTools.ComputeEqualRadius
TPrsStd_ConstraintTools_ComputeFix = TPrsStd_ConstraintTools.ComputeFix
TPrsStd_ConstraintTools_ComputeMaxRadius = TPrsStd_ConstraintTools.ComputeMaxRadius
TPrsStd_ConstraintTools_ComputeMidPoint = TPrsStd_ConstraintTools.ComputeMidPoint
TPrsStd_ConstraintTools_ComputeMinRadius = TPrsStd_ConstraintTools.ComputeMinRadius
TPrsStd_ConstraintTools_ComputeOffset = TPrsStd_ConstraintTools.ComputeOffset
TPrsStd_ConstraintTools_ComputeOthers = TPrsStd_ConstraintTools.ComputeOthers
TPrsStd_ConstraintTools_ComputeParallel = TPrsStd_ConstraintTools.ComputeParallel
TPrsStd_ConstraintTools_ComputePerpendicular = TPrsStd_ConstraintTools.ComputePerpendicular
TPrsStd_ConstraintTools_ComputePlacement = TPrsStd_ConstraintTools.ComputePlacement
TPrsStd_ConstraintTools_ComputeRadius = TPrsStd_ConstraintTools.ComputeRadius
TPrsStd_ConstraintTools_ComputeRound = TPrsStd_ConstraintTools.ComputeRound
TPrsStd_ConstraintTools_ComputeSymmetry = TPrsStd_ConstraintTools.ComputeSymmetry
TPrsStd_ConstraintTools_ComputeTangent = TPrsStd_ConstraintTools.ComputeTangent
TPrsStd_ConstraintTools_ComputeTextAndValue = TPrsStd_ConstraintTools.ComputeTextAndValue
TPrsStd_ConstraintTools_UpdateOnlyValue = TPrsStd_ConstraintTools.UpdateOnlyValue
TPrsStd_DriverTable_Get = TPrsStd_DriverTable.Get



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.XmlMDF import *
from OCC.Core.Message import *
from OCC.Core.TDF import *
from OCC.Core.XmlObjMgt import *


class xmlmdatastd:
	@staticmethod
	def AddDrivers(aDriverTable: XmlMDF_ADriverTable, anMsgDrv: Message_Messenger) -> None: ...

class XmlMDataStd_AsciiStringDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_BooleanArrayDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_BooleanListDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_ByteArrayDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_ExpressionDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_ExtStringArrayDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_ExtStringListDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_GenericEmptyDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...
	def SourceType(self) -> Standard_Type: ...

class XmlMDataStd_GenericExtStringDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...
	def SourceType(self) -> Standard_Type: ...

class XmlMDataStd_IntPackedMapDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_IntegerArrayDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_IntegerDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_IntegerListDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_NamedDataDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_RealArrayDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_RealDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_RealListDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_ReferenceArrayDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_ReferenceListDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_TreeNodeDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_UAttributeDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMDataStd_VariableDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

xmlmdatastd_AddDrivers = xmlmdatastd.AddDrivers
